SWDEV-532473 - Add Pcie atomic support check to failing tests (#575)

Co-authored-by: Rahul Manocha <rmanocha@amd.com>
Tento commit je obsažen v:
systems-assistant[bot]
2025-09-09 09:01:25 -07:00
odevzdal GitHub
rodič 5f517d37ee
revize be2e7314fa
5 změnil soubory, kde provedl 18 přidání a 26 odebrání
-3
Zobrazit soubor
@@ -43,7 +43,6 @@ static __global__ void kerTestDeviceMalloc(size_t size) {
if (myId == 0) {
dev_common_ptr = reinterpret_cast<char*>(malloc(size));
if (dev_common_ptr == nullptr) {
printf("Device Allocation Failed! \n");
return;
}
}
@@ -57,7 +56,6 @@ static __global__ void kerTestDeviceWrite() {
int myId = threadIdx.x + blockDim.x * blockIdx.x;
// Allocate
if (dev_common_ptr == nullptr) {
printf("Device Allocation Failed! \n");
return;
}
*(dev_common_ptr + myId) = SCHAR_MAX;
@@ -95,7 +93,6 @@ static __global__ void kerTestDeviceNew(size_t size) {
if (myId == 0) {
dev_common_ptr = new char[size];
if (dev_common_ptr == nullptr) {
printf("Device Allocation Failed! \n");
return;
}
}
+6 -6
Zobrazit soubor
@@ -102,7 +102,7 @@ bool static TstCoherency(int* Ptr, bool HmmMem) {
// The following test is failing on Nvidia platform hence disabled it for now
#if HT_AMD
TEST_CASE("Unit_malloc_CoherentTst") {
CHECK_PCIE_ATOMICS_SUPPORT
CHECK_PCIE_ATOMIC_SUPPORT
hipDeviceProp_t prop;
HIPCHECK(hipGetDeviceProperties(&prop, 0));
char* p = NULL;
@@ -164,7 +164,7 @@ TEST_CASE("Unit_malloc_CoherentTstWthAdvise") {
// The following test is failing on Nvidia platform hence disabling it for now
#if HT_AMD
TEST_CASE("Unit_mmap_CoherentTst") {
CHECK_PCIE_ATOMICS_SUPPORT
CHECK_PCIE_ATOMIC_SUPPORT
hipDeviceProp_t prop;
HIPCHECK(hipGetDeviceProperties(&prop, 0));
char* p = NULL;
@@ -408,7 +408,7 @@ TEST_CASE("Unit_hipHostMalloc_WthEnv1") {
}
int stat = 0;
if (fork() == 0) { // child process
CHECK_PCIE_ATOMICS_SUPPORT
CHECK_PCIE_ATOMIC_SUPPORT;
int *Ptr = nullptr, SIZE = sizeof(int);
bool HmmMem = false;
// Allocating hipHostMalloc() memory
@@ -437,7 +437,7 @@ TEST_CASE("Unit_hipHostMalloc_WthEnv1Flg1") {
}
int stat = 0;
if (fork() == 0) { // child process
CHECK_PCIE_ATOMICS_SUPPORT
CHECK_PCIE_ATOMIC_SUPPORT
int *Ptr = nullptr, SIZE = sizeof(int);
bool HmmMem = false;
// Allocating hipHostMalloc() memory
@@ -465,7 +465,7 @@ TEST_CASE("Unit_hipHostMalloc_WthEnv1Flg2") {
}
int stat = 0;
if (fork() == 0) { // child process
CHECK_PCIE_ATOMICS_SUPPORT
CHECK_PCIE_ATOMIC_SUPPORT
int *Ptr = nullptr, SIZE = sizeof(int);
bool HmmMem = false;
// Allocating hipHostMalloc() memory
@@ -493,7 +493,7 @@ TEST_CASE("Unit_hipHostMalloc_WthEnv1Flg3") {
}
int stat = 0;
if (fork() == 0) { // child process
CHECK_PCIE_ATOMICS_SUPPORT
CHECK_PCIE_ATOMIC_SUPPORT
int *Ptr = nullptr, SIZE = sizeof(int);
bool HmmMem = false;
// Allocating hipHostMalloc() memory